@@ -12,6 +12,19 @@ use crate::ThemeStyles;
 
 /**
 Create a custom [MietteHandler] from options.
+
+## Example
+
+```no_run
+miette::set_hook(Box::new(|_| {
+    Box::new(miette::MietteHandlerOpts::new()
+        .terminal_links(true)
+        .unicode(false)
+        .context_lines(3)
+        .build())
+}))
+# .unwrap();
+```
 */
 #[derive(Default, Debug, Clone)]
 pub struct MietteHandlerOpts {
